﻿using Cop.Borovkov.Var3.Models;
using PIHelperSh.PdfCreator;
using PIHelperSh.PdfCreator.Enums;
using PIHelperSh.PdfCreator.Interfaces;
using PIHelperSh.PdfCreator.Models.TableModels;
using System.ComponentModel;

namespace Cop.Borovkov.Var3.Components
{
    /// <summary>
    /// Компонент для сохранения таблицы в пдф
    /// </summary>
    public partial class CustomPdfTable : Component
    {
        /// <summary>
        /// </summary>
        public CustomPdfTable()
        {
            InitializeComponent();
        }

        /// <summary>
        /// </summary>
        /// <param name="container"></param>
        public CustomPdfTable(IContainer container)
        {
            container.Add(this);
            InitializeComponent();
        }

        /// <summary>
        /// Сохранить набор таблиц в пдф
        /// </summary>
        /// <param name="fileName"></param>
        /// <param name="title"></param>
        /// <param name="tables"></param>
        public void SaveToPdf(PdfTableInfo tableInfo)
        {
            if (!tableInfo.Tables.Any())
            {
                return;
            }

            PdfCreator creator = new PdfCreator();

            creator.AddParagraph(new()
            {
                Style = PdfStyleType.Title,
                Text = tableInfo.Title,
                MarginAfter = PdfMargin.Smal,
            });

            foreach (string[,] table in tableInfo.Tables)
            {
                List<PDFSimpleTableRow> rows = new();

                for (int i = 0; i < table.GetLength(0); ++i)
                {
                    PDFSimpleTableRow row = new();

                    for (int j = 0; j < table.GetLength(1); ++j)
                    {
                        row.Items.Add(table[i, j]);
                    }

                    rows.Add(row);
                }

                creator.AddSimpleTable(new()
                {
                    Header = rows.First().Items.Select(item => new PdfTableColumn() 
                    { 
                        Title = item,  
                        Size = 3,
                    } as IPdfColumnItem).ToList(),
                    Rows = rows.Skip(1).ToList(),

                    HeaderStyle = PdfStyleType.Basic,
                    HeaderHorizontalAlignment = PdfAlignmentType.Left,
                    RowHorizontalAlignment = PdfAlignmentType.Left,
                });

                creator.AddParagraph(new()
                {
                    MarginAfter = PdfMargin.Smal,
                });
            }

            creator.SavePdf(tableInfo.FilePath);
        }
    }
}
