﻿using AutoMapper;
using Lab3.Database.Context;
using Lab3.Database.DTO;
using Lab3.Database.Models;
using Lab3.Database.Repository.Interfaces;
using Microsoft.EntityFrameworkCore;

namespace Lab3.Database.Repository.Implementations
{
    public class StudentRepository : IStudentRepository
    {
        private readonly IMapper _mapper;
     
        private readonly COPContext _context;

        public StudentRepository(IMapper mapper, COPContext context)
        {
            _mapper = mapper;
            _context = context;
        }

        public async Task<StudentDTO> CreateAsync(StudentDTO studentDTO)
        {
            var student = _mapper.Map<Student>(studentDTO);

            var result = await _context.Students.AddAsync(student);
            await _context.SaveChangesAsync();

            return _mapper.Map<StudentDTO>(result.Entity);
        }

        public async Task<StudentDTO?> DeleteAsync(Guid id)
        {
            var student = await _context.Students.FindAsync(id);

            if (student == null)
            {
                return null;
            }

            var result = _context.Students.Remove(student);
            await _context.SaveChangesAsync();

            return _mapper.Map<StudentDTO>(result.Entity);
        }

        public async Task<List<StudentDTO>> GetAsync(int limit = 10000, int offset = 0) 
            => _mapper.Map<List<StudentDTO>>(
                await _context.Students
                    .Include(s => s.StudentSessions)
                    .Skip(offset)
                    .Take(limit)
                    .ToListAsync());

        public async Task<StudentDTO?> GetAsync(Guid id)
        {
            return _mapper.Map<StudentDTO>(
                await _context.Students
                    .Include(s => s.StudentSessions)
                    .FirstOrDefaultAsync());
        }
        
        public async Task<StudentDTO?> UpdateAsync(StudentDTO studentDTO)
        {
            var student = _mapper.Map<Student>(studentDTO);

            var currStudent = await _context.Students.FindAsync(student.Id);

            if (currStudent == null)
            {
                return null;
            }

            currStudent.Name = student.Name;
            currStudent.StartEducation = student.StartEducation;
            currStudent.EducationForm = student.EducationForm;

            foreach (var session in currStudent.StudentSessions)
            {
                session.Score = student.StudentSessions
                    .FirstOrDefault(s => s.Number == session.Number)?.Score ?? session.Score;
            }

            await _context.SaveChangesAsync();

            return _mapper.Map<StudentDTO>(currStudent);
        }
    }
}
