﻿using Lab3.Database.Repository.Interfaces;

namespace Lab3.Forms
{
    public partial class CatalogForm : Form
    {
        private readonly IEducationFormRepository _repository;

        public CatalogForm(IEducationFormRepository educationFormRepository)
        {
            _repository = educationFormRepository;
            InitializeComponent();
        }

        private async void CatalogForm_LoadAsync(object sender, EventArgs e)
        {
            Catalog.Rows.Clear();

            var values = (await _repository.Get()).ToList();
            for (int i = 0; i < values.Count; i++)
            {
                Catalog.Rows.Add();
                Catalog.Rows[i].Cells[0].Value = values[i];
            }
        }

        private async void Catalog_CellEndEditAsync(object sender, DataGridViewCellEventArgs e)
        {
            await LoadAsync();
        }

        private async Task LoadAsync()
        {
            try
            {
                List<string> values = new List<string>();

                for (int i = 0; i < Catalog.Rows.Count; ++i)
                {
                    string? val = (string?)Catalog.Rows[i].Cells[0].Value;
                    if (string.IsNullOrEmpty(val))
                    {
                        MessageBox.Show(
                            "Неверные данные",
                            "Ошибка",
                            MessageBoxButtons.OK,
                            MessageBoxIcon.Error);
                        return;
                    }
                    values.Add(val);
                }

                await _repository.Update(values);
            }
            catch (Exception ex)
            {
                MessageBox.Show(
                    ex.Message,
                    "Ошибка",
                    MessageBoxButtons.OK,
                    MessageBoxIcon.Error);
            }
        }

        private async void Catalog_KeyDownAsync(object sender, KeyEventArgs e)
        {
            if  (e.KeyCode == Keys.Insert)
            {
                Catalog.Rows.Add();
            }

            if (e.KeyCode == Keys.Delete && Catalog.SelectedRows.Count == 1)
            {
                if (MessageBox.Show(
                    "Удалить?",
                    "Удаление",
                    MessageBoxButtons.YesNo,
                    MessageBoxIcon.Question) == DialogResult.Yes)
                {
                    try
                    {
                        Catalog.Rows.RemoveAt(Catalog.SelectedRows[0].Index);
                        await LoadAsync();
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(
                            ex.Message,
                            "Ошибка",
                            MessageBoxButtons.OK,
                            MessageBoxIcon.Error);
                    }
                }
            }
        }
    }
}
